@@ -1,6 +1,6 @@
 package IRC::Mode::Set;
 {
-  $IRC::Mode::Set::VERSION = '0.073000';
+  $IRC::Mode::Set::VERSION = '0.074000';
 }
 
 use 5.10.1;
@@ -87,23 +87,7 @@ has mode_string => (
 
 sub _build_mode_string {
   my ($self) = @_;
-
-  my ($pstr, $mstr);
-  my $curflag = '';
-
-  for my $cset (@{ $self->mode_array }) {
-    my ($flag, $mode, $param) = @$cset;
-    if ($flag eq $curflag) {
-      $mstr   .= $mode;
-    } else {
-      $mstr   .= $flag . $mode;
-      $curflag = $flag;
-    }
-    $pstr     .= " $param" if defined $param;
-  }
-
-  $mstr .= $pstr if length $pstr;
-  $mstr
+  array_to_mode( $self->mode_array )
 }
 
 
